summaryrefslogtreecommitdiff
path: root/BlankConsoleLab/BlankConsoleLab.cpp
diff options
context:
space:
mode:
author[email protected] <[email protected]>2022-10-05 16:16:30 -0700
committer[email protected] <[email protected]>2022-10-05 16:16:30 -0700
commit9bac023d635846d7a4160605786317e3e0ef363e (patch)
tree876efb69b279e8df737c4f15ae3e47062ad4a84c /BlankConsoleLab/BlankConsoleLab.cpp
parentSetting up GitHub Classroom Feedback (diff)
downloadcst116-lab1-smith-9bac023d635846d7a4160605786317e3e0ef363e.tar.xz
cst116-lab1-smith-9bac023d635846d7a4160605786317e3e0ef363e.zip
push 1
Diffstat (limited to 'BlankConsoleLab/BlankConsoleLab.cpp')
-rw-r--r--BlankConsoleLab/BlankConsoleLab.cpp49
1 files changed, 43 insertions, 6 deletions
diff --git a/BlankConsoleLab/BlankConsoleLab.cpp b/BlankConsoleLab/BlankConsoleLab.cpp
index ed5f807..ee35f4d 100644
--- a/BlankConsoleLab/BlankConsoleLab.cpp
+++ b/BlankConsoleLab/BlankConsoleLab.cpp
@@ -1,16 +1,53 @@
// BlankConsoleLab.cpp : This file contains the 'main' function. Program execution begins and ends there.
//
#include <iostream>
-using namespace std;
-
-using std::cout;
using std::cin;
+using std::cout;
using std::endl;
+//Initializing Variables
+float w, l, area, aspect_ratio;
+
int main()
{
- cout << "Hello World!\n";
+ //Collecting the length and width of the kite in centimeters
+ while !(w >= 1)
+ cout << "Please input the width of the kite in centimeters." << endl;
+ cin >> w;
+ cout << "Now please input the length of the kite in centimeters." << endl;
+ cin >> l;
+
+ //Doing the math to convert the centimeter inputs to square meter outputs
+ area = (w * l) / 2;
+ area /= 10000;
+
+ //Displaying the area in square meters
+ cout << "The area of the kite in square meters is: " << area << endl << endl;
+
+ //Setting the aspect ratio of width to length
+ aspect_ratio = w / l;
+
+ //Determining if the aspect ratio is too high
+ if (aspect_ratio >= 1) {
+ cout << "Your aspect ratio of width to length is: " << aspect_ratio << ", which is quite high." << endl << "It is recommended to use a smaller aspect ratio to maintain stability." << endl << endl;
+ }
+
+ return 0;
}
+// Run program: Ctrl + F5 or Debug > Start Without Debugging menu
+// Debug program: F5 or Debug > Start Debugging menu
+
+// Tips for Getting Started:
+// 1. Use the Solution Explorer window to add/manage files
+// 2. Use the Team Explorer window to connect to source control
+// 3. Use the Output window to see build output and other messages
+// 4. Use the Error List window to view errors
+// 5. Go to Project > Add New Item to create new code files, or Project > Add Existing Item to add existing code files to the project
+// 6. In the future, to open this project again, go to File > Open > Project and select the .sln file
@@ -1,16 +1,53 @@
-// BlankConsoleLab.cpp : This file contains the 'main' function. Program execution begins and ends there.
-//
+// CST116-Lab1-Smith.cpp : This file contains the 'main' function. Program execution begins and ends there.
+/*Benjamin Smith
+* CST116
+* Lab 1
+* Input and Output and If statements
+*/
#include <iostream>